@@ -11,9 +11,10 @@
 #'
 #' If any of the \code{dirs} is \code{"bootstrap"} it is treated specially.
 #' Instead of completely removing the \verb{bootstrap} directory, only the
-#' subdirectories \verb{data}, \verb{library}, and \verb{software} are removed.
-#' This protects the subdirectory \verb{bootstrap/initial} and \verb{*.bib}
-#' metadata files from being accidentally deleted.
+#' subdirectories \verb{config}, \verb{data}, \verb{library}, and
+#' \verb{software} are removed. This protects the subdirectory
+#' \verb{bootstrap/initial} and \verb{*.bib} metadata files from being
+#' accidentally deleted.
 #'
 #' @seealso
 #' \code{\link{mkdir}} and \code{\link{rmdir}} create and remove empty
@@ -32,11 +33,16 @@
 
 clean <- function(dirs=c("data", "model", "output", "report"))
 {
+  ## Convert "bootstrap/" to "bootstrap", so clean("bootstrap/") doesn't go wild
+  dirs <- sub("/$", "", dirs)
+
   if("bootstrap" %in% dirs)
   {
-    unlink(c("bootstrap/data", "bootstrap/library", "bootstrap/software"),
-           recursive=TRUE)
+    ## An odd directory called 'library:' can appear in Linux
+    unlink(c("bootstrap/config", "bootstrap/data", "bootstrap/library",
+             "bootstrap/library:", "bootstrap/software"), recursive=TRUE)
     dirs <- dirs[dirs != "bootstrap"]
   }
+
   unlink(dirs, recursive=TRUE)
 }
