@@ -39,11 +39,8 @@ makeTAF <- function(script, ...)
                 "data.R"=make("data.R",
                               dir(pattern="^data_.*\\.R$"),
                               "data", engine=sourceTAF, ...),
-                "input.R"=make("input.R",
-                               c("data",dir(pattern="^input_.*\\.R$")),
-                               "input", engine=sourceTAF, ...),
                 "model.R"=make("model.R",
-                               c("input",dir(pattern="^model_.*\\.R$")),
+                               c("data",dir(pattern="^model_.*\\.R$")),
                                "model", engine=sourceTAF, ...),
                 "output.R"=make("output.R",
                                 c("model",dir(pattern="^output_.*\\.R$")),
